@@ -1,22 +1,16 @@
 module Fog
   module Monitoring
-    def self.[](provider)
-      new(:provider => provider)
-    end
+    extend Fog::ServicesMixin
 
-    def self.new(attributes)
-      attributes = attributes.dup
+    def self.new(orig_attributes)
+      attributes = orig_attributes.dup
       provider = attributes.delete(:provider).to_s.downcase.to_sym
       if provider == :stormondemand
         require "fog/monitoring/storm_on_demand"
         Fog::Monitoring::StormOnDemand.new(attributes)
       else
-        raise ArgumentError, "#{provider} has no monitoring service"
+        super(orig_attributes)
       end
     end
-
-    def self.providers
-      Fog.services[:monitoring]
-    end
   end
 end
