@@ -33,12 +33,6 @@ def collection_tests(collection, params = {}, mocks_implemented = true)
       methods = %w(all? any? find detect collect map find_index flat_map
                    collect_concat group_by none? one?)
 
-      # JRuby 1.7.5+ issue causes a SystemStackError: stack level too deep
-      # https://github.com/jruby/jruby/issues/1265
-      if RUBY_PLATFORM == "java" && JRUBY_VERSION =~ /1\.7\.[5-8]/
-        methods.delete("all?")
-      end
-
       methods.each do |enum_method|
         next unless collection.respond_to?(enum_method)
         tests("##{enum_method}").succeeds do
