@@ -1,23 +1,17 @@
 module Fog
   module VPN
-    def self.[](provider)
-      new(:provider => provider)
-    end
+    extend Fog::ServicesMixin
 
-    def self.new(attributes)
-      attributes = attributes.dup
+    def self.new(orig_attributes)
+      attributes = orig_attributes.dup
       provider = attributes.delete(:provider).to_s.downcase.to_sym
 
       if provider == :stormondemand
         require "fog/vpn/storm_on_demand"
         Fog::VPN::StormOnDemand.new(attributes)
       else
-        raise ArgumentError, "#{provider} has no vpn service"
+        super(orig_attributes)
       end
     end
-
-    def self.providers
-      Fog.services[:vpn]
-    end
   end
 end
