@@ -1,5 +1,4 @@
 require "spec_helper"
-require "xmlrpc/datetime"
 
 class Service
   def single_associations
@@ -114,12 +113,6 @@ describe "Fog::Attributes" do
       model.merge_attributes(:time => string)
       assert_equal Time.parse(string), model.time
     end
-
-    it "returns a Time object when passed a XMLRPC::DateTime object" do
-      now = XMLRPC::DateTime.new(2000, 7, 8, 10, 20, 34)
-      model.merge_attributes(:time => now)
-      assert_equal now.to_time, model.time
-    end
   end
 
   describe ":type => :boolean" do
@@ -238,7 +231,7 @@ describe "Fog::Attributes" do
 
   describe ":default => 'default_value'" do
     it "should return nil when default is not defined on a new object" do
-      assert_equal model.bool, nil
+      assert_nil model.bool
     end
 
     it "should return the value of the object when default is not defined" do
@@ -266,18 +259,18 @@ describe "Fog::Attributes" do
 
     it "should return nil on a persisted object without a value" do
       model.merge_attributes(:id => "some-crazy-id")
-      assert_equal model.default, nil
+      assert_nil model.default
     end
 
     it "should return nil when an attribute with default value is setted to nil" do
       model.default = nil
-      assert_equal model.default, nil
+      assert_nil model.default
     end
   end
 
   describe ".has_one" do
     it "should create an instance_variable to save the association object" do
-      assert_equal model.one_object, nil
+      assert_nil model.one_object
     end
 
     it "should create a getter to save the association model" do
@@ -299,7 +292,7 @@ describe "Fog::Attributes" do
 
   describe ".has_one_identity" do
     it "should create an instance_variable to save the association identity" do
-      assert_equal model.one_identity, nil
+      assert_nil model.one_identity
     end
 
     it "should create a getter to load the association model" do
